//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[Hora](index.md)/[parentPoint](parent-point.md)

# parentPoint

[common]\

@EncodeDefault

val [parentPoint](parent-point.md): [ParentPoint](../../mahjongutils.hanhu/-parent-point/index.md)

亲家（庄家）和牌点数
